==> nextcloud-app-tasks-0.15.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/vi.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Quan trọng",
    "Today" : "Hôm nay",
    "Week" : "Tuần",
    "All" : "Tất cả",
    "Current" : "Hiện tại",
    "Completed" : "Hoàn thành",
    "Tasks" : "Nhiệm vụ",
    "The Tasks app for Nextcloud" : "Ứng dụng Nhiệm vụ cho Nextcloud",
    "Hidden" : "Ẩn",
    "Automatic" : "Tự động",
    "Share with users or groups" : "Chia sẽ với người dùng hoặc nhóm",
    "No users or groups" : "Không có người dùng hay nhóm",
    "Can edit" : "Có thể chỉnh sửa",
    "Unshare with {displayName}" : "Gỡ chia sẻ với {displayName}",
    "Unable to delete the share." : "Không thể xóa chia sẻ.",
    "Unable to change permissions." : "Không thể thay đổi quyền hạn.",
    "Edit" : "Sửa",
    "Copy private link" : "Sao chép liên kết riêng tư",
    "Copied" : "Đã sao chép",
    "Export" : "Xuất ra",
    "Delete" : "Xóa",
    "Unshare" : "Bỏ chia sẽ",
    "Calendar link copied to clipboard." : "Liên kết của lịch đã được sao chép vào bảng tạm.",
    "Calendar link could not be copied to clipboard." : "liên kết của lịch không thể sao chép vào bảng tạm.",
    "The name \"{calendar}\" is already used." : "Tên \"{calendar}\" đã được sử dụng.",
    "An empty name is not allowed." : "Để trống tên không được cho phép.",
    "An error occurred, unable to delete the calendar." : "Một lỗi đã xảy ra, không thể xóa lịch.",
    "Trash bin" : "Thùng rác",
    "Name" : "Tên",
    "Deleted" : "Đã xoá",
    "Restore" : "Khôi phục",
    "Delete permanently" : "Xoá vĩnh viễn",
    "Empty trash bin" : "Dọn thùng rác",
    "Untitled task" : "Nhiệm vụ không tiêu đề",
    "Untitled event" : "Sự kiện không tiêu đề",
    "Unknown calendar" : "Lịch không rõ nguồn",
    "Could not load deleted calendars and objects" : "Không thể hiển thị lịch hoặc các đối tượng đã xoá",
    "Could not restore calendar or event" : "Không thể khôi phục lịch hoặc sự kiện",
    "Do you really want to empty the trash bin?" : "Bạn có chắc là muốn dọn sạch thùng rác hay không?",
    "No errors" : "Không có lỗi",
    "Open your browser console for more details" : "Mở trong trình duyệt để biết thêm chi tiết",
    "Due date" : "Thời hạn",
    "Last modified" : "Lần cuối chỉnh sửa",
    "[Yesterday]" : "[Hôm qua]",
    "[Today]" : "[Hôm nay]",
    "[Tomorrow]" : "[Ngày mai]",
    "Cancel" : "Hủy",
    "Close" : "Đóng",
    "Tomorrow" : "Ngày mai",
    "Add List…" : "Thêm vào danh sách…",
    "All day" : "Cả ngày",
    "Edit title" : "Chỉnh sửa tiêu đề",
    "Details" : "Chi tiết",
    "Select tags" : "Chọn một thẻ",
    "Notes" : "Ghi chú",
    "Reminders" : "Nhắc nhở",
    "Repeat" : "Lặp lại",
    "When shared show full event" : "Khi được chia sẻ thì thể hiện đầy đủ sự kiện",
    "When shared show only busy" : "Khi được chia sẻ thì chỉ thể hiện đang bận",
    "When shared hide this event" : "Khi được chia sẻ thì ẩn sự kiện này đi",
    "Canceled" : "Đã bị hủy",
    "An error occurred" : "Có lỗi đã xảy ra"
},
"nplurals=1; plural=0;");

==> nextcloud-app-tasks-0.16.1-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/vi.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Quan trọng",
    "Today" : "Hôm nay",
    "Week" : "Tuần",
    "All" : "Tất cả",
    "Current" : "Hiện tại",
    "Completed" : "Hoàn thành",
    "Tasks" : "Nhiệm vụ",
    "The Tasks app for Nextcloud" : "Ứng dụng Nhiệm vụ cho Nextcloud",
    "Hidden" : "Ẩn",
    "Visible" : "Có thể nhìn thấy",
    "Automatic" : "Tự động",
    "Share with users or groups" : "Chia sẽ với người dùng hoặc nhóm",
    "No users or groups" : "Không có người dùng hay nhóm",
    "Can edit" : "Có thể chỉnh sửa",
    "Unshare with {displayName}" : "Gỡ chia sẻ với {displayName}",
    "Unable to delete the share." : "Không thể xóa chia sẻ.",
    "Unable to change permissions." : "Không thể thay đổi quyền hạn.",
    "Edit" : "Sửa",
    "Copy private link" : "Sao chép liên kết riêng tư",
    "Copied" : "Đã sao chép",
    "Export" : "Xuất ra",
    "Delete" : "Xóa",
    "Unshare" : "Bỏ chia sẽ",
    "List name" : "Danh sách tên",
    "Calendar link copied to clipboard." : "Liên kết của lịch đã được sao chép vào bảng tạm.",
    "Calendar link could not be copied to clipboard." : "liên kết của lịch không thể sao chép vào bảng tạm.",
    "The name \"{calendar}\" is already used." : "Tên \"{calendar}\" đã được sử dụng.",
    "An empty name is not allowed." : "Để trống tên không được cho phép.",
    "An error occurred, unable to delete the calendar." : "Một lỗi đã xảy ra, không thể xóa lịch.",
    "Trash bin" : "Thùng rác",
    "Name" : "Tên",
    "Deleted" : "Đã xoá",
    "Restore" : "Khôi phục",
    "Delete permanently" : "Xoá vĩnh viễn",
    "Empty trash bin" : "Dọn thùng rác",
    "Untitled task" : "Nhiệm vụ không tiêu đề",
    "Untitled event" : "Sự kiện không tiêu đề",
    "Unknown calendar" : "Lịch không rõ nguồn",
    "Could not load deleted calendars and objects" : "Không thể hiển thị lịch hoặc các đối tượng đã xoá",
    "Could not restore calendar or event" : "Không thể khôi phục lịch hoặc sự kiện",
    "Do you really want to empty the trash bin?" : "Bạn có chắc là muốn dọn sạch thùng rác hay không?",
    "Cancel" : "Hủy",
    "Close" : "Đóng",
    "No errors" : "Không có lỗi",
    "Open your browser console for more details" : "Mở trong trình duyệt để biết thêm chi tiết",
    "Select tags to filter by" : "Chọn nhãn để lọc theo",
    "Due date" : "Thời hạn",
    "Last modified" : "Lần cuối chỉnh sửa",
    "Alphabetically" : "Theo bảng chữ cái",
    "Delete task" : "Xóa nhiệm vụ",
    "[Yesterday]" : "[Hôm qua]",
    "[Today]" : "[Hôm nay]",
    "[Tomorrow]" : "[Ngày mai]",
    "Tomorrow" : "Ngày mai",
    "Add List…" : "Thêm vào danh sách…",
    "All day" : "Cả ngày",
    "Details" : "Chi tiết",
    "Select tags" : "Chọn một thẻ",
    "Notes" : "Ghi chú",
    "Reminders" : "Nhắc nhở",
    "Repeat" : "Lặp lại",
    "When shared show full event" : "Khi được chia sẻ thì thể hiện đầy đủ sự kiện",
    "When shared show only busy" : "Khi được chia sẻ thì chỉ thể hiện đang bận",
    "When shared hide this event" : "Khi được chia sẻ thì ẩn sự kiện này đi",
    "Canceled" : "Đã bị hủy",
    "Mark as done" : "Đánh dấu là đã hoàn thành",
    "An error occurred" : "Có lỗi đã xảy ra",
    "Message from {author} in {conversationName}" : "Tin nhắn từ {author} trong {conversationName}"
},
"nplurals=1; plural=0;");
